==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/sr/lang.php <==
<?php
/**
 * Serbian language file
 *
 * @author Иван Петровић petrovicivan@ubuntusrbija.org
 */
$lang['menu']                  = 'Управљач корисницима';
$lang['noauth']                = '(корисничка провера није доступна)';
$lang['nosupport']             = '(уптављање корисницима није подржано)';
$lang['badauth']               = 'неисправан механизам провере';
$lang['user_id']               = 'Корисник';
$lang['user_pass']             = 'Лозинка';
$lang['user_name']             = 'Име и презиме';
$lang['user_mail']             = 'Е-адреса';
$lang['user_groups']           = 'Групе';
$lang['field']                 = 'Поље';
$lang['value']                 = 'Вредност';
$lang['add']                   = 'Додај';
$lang['delete']                = 'Обриши';
$lang['delete_selected']       = 'Обриши одабране';
$lang['edit']                  = 'Измени';
$lang['edit_prompt']           = 'Измени корисника';
$lang['modify']                = 'Сачувај измене';
$lang['search']                = 'Претрага';
$lang['search_prompt']         = 'Изведи претрагу';
$lang['clear']                 = 'Поништи филтер претраге';
$lang['filter']                = 'Филтер';
$lang['summary']               = 'Приказ %1$d-%2$d од %3$d пронађена корисника. Укупно има %4$d корисника.';
$lang['nonefound']             = 'Није пронађен корисник. Укупно има %d корисника.';
$lang['delete_ok']             = '%d корисника је обрисано';
$lang['delete_fail']           = '%d брисања није успело.';
$lang['update_ok']             = 'Кориснички налог је ажуриран';
$lang['update_fail']           = 'Кориснички налог није ажуриран';
$lang['update_exists']         = 'Измена корисничког имена није успела, наведени корисник (%s) већ постоји (остале измене ће бити примењене).';
$lang['start']                 = 'почетак';
$lang['prev']                  = 'претходна';
$lang['next']                  = 'следећа';
$lang['last']                  = 'крај';
$lang['edit_usermissing']      = 'Одабрани корисник не постоји, наведено корисничко име је можда обрисано или је измењено негде другде.';
$lang['user_notify']           = 'Обавести корисника';
$lang['note_notify']           = 'Потврдна порука ће бити послата једино ако је кориснику додељена нова лозинка.';
$lang['note_group']            = 'Нови корисници ће бити додељени подразумеваној групи (%s) ако није другачије назначено.';
$lang['add_ok']                = 'Корисник је успешно додат';
$lang['add_fail']              = 'Додавање корисника није успело';
$lang['notify_ok']             = 'Порука са обавештењен је послата';
$lang['notify_fail']           = 'Порука са обавештењен није послата';

==> dokuwiki_0.0.20160626.a.orig.tar.gz: dokuwiki-2016-06-26a/lib/plugins/usermanager/lang/sr/lang.php <==
<?php
/**
 * Serbian language file
 *
 * @author Иван Петровић petrovicivan@ubuntusrbija.org
 * @author Ivan Petrovic <petrovicivan@ubuntusrbija.org>
 * @author Miroslav Šolti <solti.miroslav@gmail.com>
 */
$lang['menu']                  = 'Управљач корисницима';
$lang['noauth']                = '(корисничка провера није доступна)';
$lang['nosupport']             = '(уптављање корисницима није подржано)';
$lang['badauth']               = 'неисправан механизам провере';
$lang['user_id']               = 'Корисник';
$lang['user_pass']             = 'Лозинка';
$lang['user_name']             = 'Име и презиме';
$lang['user_mail']             = 'Е-адреса';
$lang['user_groups']           = 'Групе';
$lang['field']                 = 'Поље';
$lang['value']                 = 'Вредност';
$lang['add']                   = 'Додај';
$lang['delete']                = 'Обриши';
$lang['delete_selected']       = 'Обриши одабране';
$lang['edit']                  = 'Измени';
$lang['edit_prompt']           = 'Измени корисника';
$lang['modify']                = 'Сачувај измене';
$lang['search']                = 'Претрага';
$lang['search_prompt']         = 'Изведи претрагу';
$lang['clear']                 = 'Поништи филтер претраге';
$lang['filter']                = 'Филтер';
$lang['summary']               = 'Приказ %1$d-%2$d од %3$d пронађена корисника. Укупно има %4$d корисника.';
$lang['nonefound']             = 'Није пронађен корисник. Укупно има %d корисника.';
$lang['delete_ok']             = '%d корисника је обрисано';
$lang['delete_fail']           = '%d брисања није успело.';
$lang['update_ok']             = 'Кориснички налог је ажуриран';
$lang['update_fail']           = 'Кориснички налог није ажуриран';
$lang['update_exists']         = 'Измена корисничког имена није успела, наведени корисник (%s) већ постоји (остале измене ће бити примењене).';
$lang['start']                 = 'почетак';
$lang['prev']                  = 'претходна';
$lang['next']                  = 'следећа';
$lang['last']                  = 'крај';
$lang['edit_usermissing']      = 'Одабрани корисник не постоји, наведено корисничко име је можда обрисано или је измењено негде другде.';
$lang['user_notify']           = 'Обавести корисника';
$lang['note_notify']           = 'Потврдна порука ће бити послата једино ако је кориснику додељена нова лозинка.';
$lang['note_group']            = 'Нови корисници ће бити додељени подразумеваној групи (%s) ако није другачије назначено.';
$lang['note_pass']             = 'Ако сте оставили поље празно и укључили обавештавање корисника лозинка ће бити аутоматски генерисана.';
$lang['add_ok']                = 'Корисник је успешно додат';
$lang['add_fail']              = 'Додавање корисника није успело';
$lang['notify_ok']             = 'Порука са обавештењен је послата';
$lang['notify_fail']           = 'Порука са обавештењен није послата';
